Author: mseidel
Date: Thu May 31 17:29:02 2018
New Revision: 1832633

URL: http://svn.apache.org/viewvc?rev=1832633&view=rev
Log:
Fixed typos:
 contructor -> constructor
 convinient -> convenient

Modified:
    openoffice/trunk/main/chart2/source/inc/NameContainer.hxx
    openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx
    openoffice/trunk/main/cui/source/dialogs/cuihyperdlg.cxx
    openoffice/trunk/main/cui/source/dialogs/hldocntp.cxx
    openoffice/trunk/main/cui/source/dialogs/hldoctp.cxx
    openoffice/trunk/main/cui/source/dialogs/hlinettp.cxx
    openoffice/trunk/main/cui/source/dialogs/hlmailtp.cxx
    openoffice/trunk/main/cui/source/dialogs/hlmarkwn.cxx
    openoffice/trunk/main/cui/source/dialogs/hltpbase.cxx
    openoffice/trunk/main/dbaccess/source/ui/inc/ScrollHelper.hxx
    openoffice/trunk/main/filter/source/pdf/pdfexport.cxx
    openoffice/trunk/main/i18npool/source/collator/collator_unicode.cxx
    
openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java
    openoffice/trunk/main/sal/inc/rtl/strbuf.hxx
    openoffice/trunk/main/sal/inc/rtl/ustrbuf.hxx
    openoffice/trunk/main/stoc/source/javaloader/javaloader.cxx
    openoffice/trunk/main/svx/sdi/fmslots.sdi
    openoffice/trunk/main/sw/inc/tox.hxx
    openoffice/trunk/main/toolkit/source/awt/vclxtoolkit.cxx
    
openoffice/trunk/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/records/Worksheet.java

Modified: openoffice/trunk/main/chart2/source/inc/NameContainer.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/inc/NameContainer.hxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/inc/NameContainer.hxx (original)
+++ openoffice/trunk/main/chart2/source/inc/NameContainer.hxx Thu May 31 
17:29:02 2018
@@ -82,7 +82,7 @@ public:
     virtual ::com::sun::star::uno::Reference< 
::com::sun::star::util::XCloneable > SAL_CALL createClone() throw 
(::com::sun::star::uno::RuntimeException);
 
 private: //methods
-    NameContainer();//no default contructor
+    NameContainer();//no default constructor
 
 private: //member
     const ::com::sun::star::uno::Type   m_aType;

Modified: 
openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx 
(original)
+++ openoffice/trunk/main/comphelper/inc/comphelper/implementationreference.hxx 
Thu May 31 17:29:02 2018
@@ -152,7 +152,7 @@ namespace comphelper
             queried for the template-parameterized UNO type.
 
             @param dummy
-            Dummy parameter, to distinguish this contructor from the
+            Dummy parameter, to distinguish this constructor from the
             default unary one (which does not perform a
             QueryInterface)
          */
@@ -192,7 +192,7 @@ namespace comphelper
                        interface
          */
         ImplementationType*            get() { return mpImpl; }
-        const ImplementationType*      get() const { return mpImpl; }        
+        const ImplementationType*      get() const { return mpImpl; }
 
         /** Release all references
 
@@ -206,7 +206,7 @@ namespace comphelper
                This method releases the UNO interface reference, and
                clears the C++ pointer to NULL.
          */
-        void                                           dispose() { mxRef = 
NULL; mpImpl=NULL; }        
+        void                                           dispose() { mxRef = 
NULL; mpImpl=NULL; }
 
         ImplementationType*            operator->() { return mpImpl; }
         const ImplementationType*      operator->() const { return mpImpl; }

Modified: openoffice/trunk/main/cui/source/dialogs/cuihyperdlg.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/dialogs/cuihyperdlg.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/dialogs/cuihyperdlg.cxx (original)
+++ openoffice/trunk/main/cui/source/dialogs/cuihyperdlg.cxx Thu May 31 
17:29:02 2018
@@ -92,7 +92,7 @@ void SvxHlinkCtrl::StateChanged( sal_uIn
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 

Modified: openoffice/trunk/main/cui/source/dialogs/hldocntp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/dialogs/hldocntp.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/dialogs/hldocntp.cxx (original)
+++ openoffice/trunk/main/cui/source/dialogs/hldocntp.cxx Thu May 31 17:29:02 
2018
@@ -103,7 +103,7 @@ sal_Bool SvxHyperlinkNewDocTp::ImplGetUR
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 

Modified: openoffice/trunk/main/cui/source/dialogs/hldoctp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/dialogs/hldoctp.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/dialogs/hldoctp.cxx (original)
+++ openoffice/trunk/main/cui/source/dialogs/hldoctp.cxx Thu May 31 17:29:02 
2018
@@ -41,7 +41,7 @@ sal_Char __READONLY_DATA sHTTPScheme[]
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 

Modified: openoffice/trunk/main/cui/source/dialogs/hlinettp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/dialogs/hlinettp.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/dialogs/hlinettp.cxx (original)
+++ openoffice/trunk/main/cui/source/dialogs/hlinettp.cxx Thu May 31 17:29:02 
2018
@@ -43,7 +43,7 @@ sal_Char __READONLY_DATA sTelnetScheme[]
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 

Modified: openoffice/trunk/main/cui/source/dialogs/hlmailtp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/dialogs/hlmailtp.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/dialogs/hlmailtp.cxx (original)
+++ openoffice/trunk/main/cui/source/dialogs/hlmailtp.cxx Thu May 31 17:29:02 
2018
@@ -42,7 +42,7 @@ using namespace ::com::sun::star;
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 

Modified: openoffice/trunk/main/cui/source/dialogs/hlmarkwn.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/dialogs/hlmarkwn.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/dialogs/hlmarkwn.cxx (original)
+++ openoffice/trunk/main/cui/source/dialogs/hlmarkwn.cxx Thu May 31 17:29:02 
2018
@@ -72,7 +72,7 @@ struct TargetData
 
 //########################################################################
 //#                                                                      #
-//# Tree-Window                                                                
                                                 #
+//# Tree-Window                                                          #
 //#                                                                      #
 //########################################################################
 
@@ -114,13 +114,13 @@ void SvxHlmarkTreeLBox::Paint( const Rec
 
 //########################################################################
 //#                                                                      #
-//# Window-Class                                                               
                                                 #
+//# Window-Class                                                         #
 //#                                                                      #
 //########################################################################
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 
@@ -465,7 +465,7 @@ void SvxHlinkDlgMarkWnd::ClearTree()
 
 /*************************************************************************
 |*
-|* Find Entry for Strng
+|* Find Entry for String
 |*
 |************************************************************************/
 

Modified: openoffice/trunk/main/cui/source/dialogs/hltpbase.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/cui/source/dialogs/hltpbase.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/cui/source/dialogs/hltpbase.cxx (original)
+++ openoffice/trunk/main/cui/source/dialogs/hltpbase.cxx Thu May 31 17:29:02 
2018
@@ -48,7 +48,7 @@ using namespace ::ucbhelper;
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 
@@ -90,7 +90,7 @@ SvxFramesComboBox::~SvxFramesComboBox ()
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 

Modified: openoffice/trunk/main/dbaccess/source/ui/inc/ScrollHelper.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/dbaccess/source/ui/inc/ScrollHelper.hxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/dbaccess/source/ui/inc/ScrollHelper.hxx (original)
+++ openoffice/trunk/main/dbaccess/source/ui/inc/ScrollHelper.hxx Thu May 31 
17:29:02 2018
@@ -40,7 +40,7 @@ namespace dbaui
                Link    m_aUpScroll;
                Link    m_aDownScroll;
        public:
-               /** default contructor
+               /** default constructor
                */
                OScrollHelper();
 

Modified: openoffice/trunk/main/filter/source/pdf/pdfexport.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/pdf/pdfexport.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/strbuf.hxx (original)
+++ openoffice/trunk/main/sal/inc/rtl/strbuf.hxx Thu May 31 17:29:02 2018
@@ -155,7 +155,7 @@ public:
     /**
         Fill the string data in the new string and clear the buffer.
 
-        This method is more efficient than the contructor of the string. It 
does
+        This method is more efficient than the constructor of the string. It 
does
         not copy the buffer.
 
         @return the string previously contained in the buffer.
@@ -199,7 +199,7 @@ public:
 
         The new capacity will be at least as large as the maximum of the 
current
         length (so that no contents of the buffer is destroyed) and the given
-        minimumCapacity.  If the given minimumCapacity is negative, nothing is
+        minimumCapacity. If the given minimumCapacity is negative, nothing is
         changed.
 
         @param   minimumCapacity   the minimum desired capacity.

Modified: openoffice/trunk/main/sal/inc/rtl/ustrbuf.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/ustrbuf.hxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/rtl/ustrbuf.hxx (original)
+++ openoffice/trunk/main/sal/inc/rtl/ustrbuf.hxx Thu May 31 17:29:02 2018
@@ -156,7 +156,7 @@ public:
     /**
         Fill the string data in the new string and clear the buffer.
 
-        This method is more efficient than the contructor of the string. It 
does
+        This method is more efficient than the constructor of the string. It 
does
         not copy the buffer.
 
         @return the string previously contained in the buffer.
@@ -200,7 +200,7 @@ public:
 
         The new capacity will be at least as large as the maximum of the 
current
         length (so that no contents of the buffer is destroyed) and the given
-        minimumCapacity.  If the given minimumCapacity is negative, nothing is
+        minimumCapacity. If the given minimumCapacity is negative, nothing is
         changed.
 
         @param   minimumCapacity   the minimum desired capacity.

Modified: openoffice/trunk/main/stoc/source/javaloader/javaloader.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/stoc/source/javaloader/javaloader.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/stoc/source/javaloader/javaloader.cxx (original)
+++ openoffice/trunk/main/stoc/source/javaloader/javaloader.cxx Thu May 31 
17:29:02 2018
@@ -257,7 +257,7 @@ const css::uno::Reference<XImplementatio
                 throw RuntimeException(OUString(RTL_CONSTASCII_USTRINGPARAM(
                     "javaloader error - no Java environment available")), 
css::uno::Reference<XInterface>());
 
-            // why is there no convinient contructor?
+            // why is there no convenient constructor?
             OUString 
sCppu_current_lb_name(RTL_CONSTASCII_USTRINGPARAM(CPPU_CURRENT_LANGUAGE_BINDING_NAME));
             uno_getEnvironment(&pUno_environment, sCppu_current_lb_name.pData, 
NULL);
             if(!pUno_environment)

Modified: openoffice/trunk/main/svx/sdi/fmslots.sdi
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/svx/sdi/fmslots.sdi?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/svx/sdi/fmslots.sdi (original)
+++ openoffice/trunk/main/svx/sdi/fmslots.sdi Thu May 31 17:29:02 2018
@@ -552,7 +552,7 @@ interface FormTextAttributeShell
     /**** <HACK> ****/
     // the following is a slight hack. Problem is that the form shell needs to 
translate
     // slot names/args into URL dispatch names/args. For this, the SfxSlotPool 
is used
-    // - it provides convinient methods for this. However, the "pool" is not 
really a
+    // - it provides convenient methods for this. However, the "pool" is not 
really a
     // "pool" - it only knows slots, if there is a shell on the dispatcher 
stack which
     // which is responsible for this slot.
     // So, we declare the form shell as responsible for the following slots.

Modified: openoffice/trunk/main/sw/inc/tox.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sw/inc/tox.hxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/sw/inc/tox.hxx (original)
+++ openoffice/trunk/main/sw/inc/tox.hxx Thu May 31 17:29:02 2018
@@ -332,7 +332,7 @@ class SW_DLLPUBLIC SwFormTokensHelper
 
 public:
     /**
-       contructor
+       constructor
 
        @param rTokens       vector of tokens
     */
@@ -752,7 +752,7 @@ inline const String& SwTOXBase::GetTitle
        { return aTitle; }
 
 inline const String& SwTOXBase::GetTypeName() const
-       { return GetTOXType()->GetTypeName();  }
+       { return GetTOXType()->GetTypeName(); }
 
 inline const SwForm& SwTOXBase::GetTOXForm() const
        { return aForm; }
@@ -761,7 +761,7 @@ inline void SwTOXBase::SetCreate(sal_uIn
        { nCreateType = nCreate; }
 
 inline void    SwTOXBase::SetTOXForm(const SwForm& rForm)
-       {  aForm = rForm; }
+       { aForm = rForm; }
 
 inline TOXTypes SwTOXBase::GetType() const
        { return GetTOXType()->GetType(); }

Modified: openoffice/trunk/main/toolkit/source/awt/vclxtoolkit.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/toolkit/source/awt/vclxtoolkit.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/toolkit/source/awt/vclxtoolkit.cxx (original)
+++ openoffice/trunk/main/toolkit/source/awt/vclxtoolkit.cxx Thu May 31 
17:29:02 2018
@@ -521,7 +521,7 @@ static void SAL_CALL ToolkitWorkerFuncti
 }
 }
 
-// contructor, which might initialize VCL
+// constructor, which might initialize VCL
 VCLXToolkit::VCLXToolkit( const ::com::sun::star::uno::Reference< 
::com::sun::star::lang::XMultiServiceFactory > & rSMgr ):
     cppu::WeakComponentImplHelper7<
     ::com::sun::star::awt::XToolkit,

Modified: 
openoffice/trunk/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/records/Worksheet.java
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/records/Worksheet.java?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- 
openoffice/trunk/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/records/Worksheet.java
 (original)
+++ 
openoffice/trunk/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/records/Worksheet.java
 Thu May 31 17:29:02 2018
@@ -61,7 +61,7 @@ public class Worksheet {
        }
        
        /**
-        * Default Contructor   
+        * Default Constructor  
         */
        public Worksheet() {
        }       
@@ -97,8 +97,8 @@ public class Worksheet {
        }
 
        /**
-        *      Reads a worksheet from the <code>InputStream</code> and 
contructs a
-        *      workbook object from it 
+        *      Reads a worksheet from the <code>InputStream</code> and 
constructs a
+        *      workbook object from it
         *
         * @param       is InputStream containing a Pocket Excel Data file.
         */


Reply via email to
--- openoffice/trunk/main/filter/source/pdf/pdfexport.cxx (original)
+++ openoffice/trunk/main/filter/source/pdf/pdfexport.cxx Thu May 31 17:29:02 
2018
@@ -540,9 +540,9 @@ sal_Bool PDFExport::Export( const OUStri
                                else if ( rFilterData[ nData ].Name == 
OUString( RTL_CONSTASCII_USTRINGPARAM( "PermissionPassword" ) ) )
                                        rFilterData[ nData ].Value >>= 
aPermissionPassword;
                                else if ( rFilterData[ nData ].Name == 
OUString( RTL_CONSTASCII_USTRINGPARAM( "PreparedPasswords" ) ) )
-                                   rFilterData[ nData ].Value >>= xEnc;
+                                       rFilterData[ nData ].Value >>= xEnc;
                                else if ( rFilterData[ nData ].Name == 
OUString( RTL_CONSTASCII_USTRINGPARAM( "PreparedPermissionPassword" ) ) )
-                                   rFilterData[ nData ].Value >>= 
aPreparedPermissionPassword;
+                                       rFilterData[ nData ].Value >>= 
aPreparedPermissionPassword;
                                else if ( rFilterData[ nData ].Name == 
OUString( RTL_CONSTASCII_USTRINGPARAM( "Printing" ) ) )
                                        rFilterData[ nData ].Value >>= 
mnPrintAllowed;
                                else if ( rFilterData[ nData ].Name == 
OUString( RTL_CONSTASCII_USTRINGPARAM( "Changes" ) ) )
@@ -591,7 +591,7 @@ sal_Bool PDFExport::Export( const OUStri
                 break;
             }
 
-//copy in context the values default in the contructor or set by the 
FilterData sequence of properties
+//copy in context the values default in the constructor or set by the 
FilterData sequence of properties
                        aContext.Tagged         = mbUseTaggedPDF;
 
 //values used in viewer
@@ -731,7 +731,7 @@ sal_Bool PDFExport::Export( const OUStri
             // which is sadly out out our control
             aPermissionPassword = rtl::OUString();
             aOpenPassword = rtl::OUString();
-            
+
             /*
             * FIXME: the entries are only implicitly defined by the resource 
file. Should there
             * ever be an additional form submit format this could get invalid.

Modified: openoffice/trunk/main/i18npool/source/collator/collator_unicode.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/i18npool/source/collator/collator_unicode.cxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- openoffice/trunk/main/i18npool/source/collator/collator_unicode.cxx 
(original)
+++ openoffice/trunk/main/i18npool/source/collator/collator_unicode.cxx Thu May 
31 17:29:02 2018
@@ -124,7 +124,7 @@ Collator_Unicode::loadCollatorAlgorithm(
                        /** ICU collators are loaded using a locale only.
                                ICU uses Variant as collation algorithm name 
(like de__PHONEBOOK
                                locale), note the empty territory (Country) 
designator in this special
-                               case here. The icu::Locale contructor changes 
the algorithm name to
+                               case here. The icu::Locale constructor changes 
the algorithm name to
                                uppercase itself, so we don't have to bother 
with that.
                        */
                        icu::Locale icuLocale(

Modified: 
openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================
--- 
openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java
 (original)
+++ 
openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/PropertySet.java
 Thu May 31 17:29:02 2018
@@ -85,9 +85,9 @@ XMultiPropertySet
     private HashMap _handleToPropertyMap;
     private HashMap _propertyToIdMap;
     private Property[] arProperties;
-    
+
     private int lastHandle= 1;
-    
+
     protected XPropertySetInfo propertySetInfo;
     protected MultiTypeInterfaceContainer aBoundLC= new 
MultiTypeInterfaceContainer();
     protected MultiTypeInterfaceContainer aVetoableLC= new 
MultiTypeInterfaceContainer();
@@ -114,7 +114,7 @@ XMultiPropertySet
         putProperty(prop);
         assignPropertyId(prop, id);
     }
-    
+
     /** Registers a property with this helper class and associates the 
argument id with it.
      *  It does the same as {@link #registerProperty(Property, Object)}. The 
first four 
      *  arguments are used to construct a Property object.
@@ -132,13 +132,13 @@ XMultiPropertySet
         registerProperty(p, id);
     }
 
-    /** Registers a property with this  class and associates the argument id 
with it.
-     *  It does the same as {@link #registerProperty(Property, Object)}. The 
first three 
+    /** Registers a property with this class and associates the argument id 
with it.
+     *  It does the same as {@link #registerProperty(Property, Object)}. The 
first three
      *  arguments are used to construct a Property object. The value for the 
Property.Handle
      *  is generated and does not have to be specified here. Use this method 
for registering
      *  a property if you do not care about the Property's handles.
      *  Registration has to occur during
      *  initialization of the inheriting class (i.e. within the contructor).
      *  @param name The property's name (Property.Name).
      *  @param type The property's type (Property.Type).
      *  @param attributes The property's attributes (Property.Attributes).
@@ -196,8 +196,6 @@ XMultiPropertySet
     {
         registerProperty(propertyName, propertyName, attributes);
     }
-        
-            
 
     /** Returns the Property object for a given property name or null if that 
property does 
      *  not exists (i.e. it has not been registered). Override this method 
@@ -211,7 +209,7 @@ XMultiPropertySet
     {
         return (Property) _nameToPropertyMap.get(propertyName);
     }
-    
+
     /** Returns the Property object with a handle (Property.Handle) as 
specified by the argument
      *  <em>nHandle</em>. The method returns null if there is no such property 
(i.e. it has not 
      *  been registered). Override this method if you want to implement your 
own mapping from handles 
@@ -223,7 +221,7 @@ XMultiPropertySet
     {
         return (Property) _handleToPropertyMap.get(nHandle);
     }
-    
+
     /** Returns an array of all Property objects or an array of length null if 
there
      *  are no properties. Override this method if you want to implement your 
own mapping from names 
      *  to Property objects. Then you also have to override {@link 
#initMappings}, {@link #getProperty(String)} and 
@@ -239,7 +237,7 @@ XMultiPropertySet
         }
         return arProperties;
     }
-    
+
     /** Stores a Property object so that it can be retrieved subsequently by 
      *  {@link #getProperty(String)},{@link #getProperties()},{@link 
#getPropertyByHandle(int)}.
      *  Override this method if you want to implement your own mapping from 
handles 
@@ -253,16 +251,16 @@ XMultiPropertySet
         if (prop.Handle != -1)
             _handleToPropertyMap.put(prop.Handle, prop);
     }
-    
-    /** Assigns an identifier object to a Property object so that the 
identifier 
+
+    /** Assigns an identifier object to a Property object so that the 
identifier
      *  can be obtained by {@link #getPropertyId getPropertyId} later on. The 
identifier
      *  is used to specify a certain storage for the property's value. If you 
do not
      *  override {@link #setPropertyValueNoBroadcast 
setPropertyValueNoBroadcast} or {@link #getPropertyValue(Property)}
-     *  then the argument <em>id</em> has to be a java.lang.String that equals 
the name of 
+     *  then the argument <em>id</em> has to be a java.lang.String that equals 
the name of
      *  the member variable that holds the Property's value.
-     *  Override this method if you want to implement your own mapping from 
Property objects  to ids or 
+     *  Override this method if you want to implement your own mapping from 
Property objects to ids or
      *  if you need ids of a type other then java.lang.String.
-     *  Then you also need to override {@link #initMappings initMappings} and 
{@link #getPropertyId getPropertyId}. 
+     *  Then you also need to override {@link #initMappings initMappings} and 
{@link #getPropertyId getPropertyId}.
      *  @param prop The Property object that is being assigned an id.
      *  @param id The object which identifies the storage used for the 
property's value.
      *  @see #registerProperty(Property, Object)
@@ -272,7 +270,7 @@ XMultiPropertySet
        if (id instanceof String && ((String) id).equals("") == false)
             _propertyToIdMap.put(prop, id);
     }
-    
+
     /** Returns the identifier object for a certain Property. The object must 
have been 
      *  previously assigned to the Property object by {@link #assignPropertyId 
assignPropertyId}.
      *  Override this method if you want to implement your own mapping from 
Property objects to ids.
@@ -376,7 +374,7 @@ XMultiPropertySet
     }
     //XPropertySet ----------------------------------------------------
     public Object getPropertyValue(String name) throws 
UnknownPropertyException, WrappedTargetException
-    {   
+    {
         Object ret= null;
         if (bInDispose || bDisposed)
             throw new com.sun.star.lang.DisposedException("The component has 
been disposed already");
@@ -384,7 +382,7 @@ XMultiPropertySet
         Property prop= getProperty(name);
         if (prop == null)
             throw new UnknownPropertyException("The property " + name + " is 
unknown");
-        
+
         synchronized (this) 
         {
             ret= getPropertyValue(prop);
@@ -400,7 +398,7 @@ XMultiPropertySet
         }
         return ret;
     }
-    
+
     //XPropertySet ----------------------------------------------------
     synchronized public void removePropertyChangeListener(String propName, 
XPropertyChangeListener listener) throws UnknownPropertyException, 
WrappedTargetException
     {  // all listeners are automatically released in a dispose call
@@ -434,7 +432,7 @@ XMultiPropertySet
                 
listenerContainer.removeInterface(XVetoableChangeListener.class, listener);
         }
     }
-    
+
     //XPropertySet ----------------------------------------------------
     /** Sets the value of a property. 
      *  The idl description for this interfaces, stipulates that the argument 
value is an Any. Since a java.lang.Object
@@ -508,7 +506,7 @@ XMultiPropertySet
             throw new com.sun.star.lang.IllegalArgumentException("The property 
must have a value; the MAYBEVOID attribute is not set!");
         if (bInDispose || bDisposed)
             throw new DisposedException("Component is already disposed");
-        
+
         //Check if the argument is allowed
         boolean bValueOk= false;
         if (value instanceof Any)
@@ -518,7 +516,7 @@ XMultiPropertySet
         if (! bValueOk)
             throw new com.sun.star.lang.IllegalArgumentException("No valid UNO 
type");
             
-        
+
         boolean bConversionOk= false;
         Object[] outConvertedVal= new Object[1];
         Object[] outOldValue= new Object[1];
@@ -526,7 +524,7 @@ XMultiPropertySet
         {
             bConversionOk= convertPropertyValue(prop, outConvertedVal, 
outOldValue, value);
         }
-        
+
         //The next step following the conversion is to set the new value of 
the property. Prior to this
         // the XVetoableChangeListener s have to be notified.
         if (bConversionOk)
@@ -543,7 +541,7 @@ XMultiPropertySet
             fire( new Property[]{prop}, outConvertedVal, outOldValue, false);
         }
     }
-    
+
     /** Converts a value in a way so that it is appropriate for storing as a 
property value, that is 
      *  {@link #setPropertyValueNoBroadcast setPropertyValueNoBroadcast} can 
process the value without any further 
      *  conversion. This implementation presumes that
@@ -630,7 +628,7 @@ XMultiPropertySet
                 // also get inherited fields, but only those which are public.
                 Field propField= getClass().getDeclaredField(sMember);
                 if (propField != null)
-                {   
+                {
                     curVal[0]= propField.get(this);
                     Class memberClass= propField.getType();
                     
@@ -701,7 +699,7 @@ XMultiPropertySet
         }
         return ret;
     }
-    
+
     private boolean checkType(Object obj)
     {
         if (obj == null 
@@ -716,7 +714,7 @@ XMultiPropertySet
             return true;
         return false;
     }
-    
+
     // Param object can be an Any or other object. If obj is null then the 
return value is null
     private Object convert( Class cl, Object obj) throws 
com.sun.star.lang.IllegalArgumentException
     {
@@ -777,7 +775,7 @@ XMultiPropertySet
             throw new com.sun.star.lang.IllegalArgumentException("Could not 
convert the argument");
         return retVal;
     }
-    
+
     /**  Sets the value of a property. In this implementation property values 
are stored in member variables 
      *  (see {@link #convertPropertyValue convertPropertyValue} Notification 
of property listeners
      *  does not occur in this method. By overriding this method one can take 
full control about how property values
@@ -857,7 +855,7 @@ XMultiPropertySet
         }
         return ret;
     }
-    
+
     /**
      *  This method fires events to 
XPropertyChangeListener,XVetoableChangeListener and
      *  XPropertiesChangeListener event sinks.
@@ -963,7 +961,7 @@ XMultiPropertySet
             throw new UnknownPropertyException(" The property with handle : " 
+ nHandle +" is unknown");
         setPropertyValue(prop, aValue);
     }
-    
+
     // XFastPropertySet 
--------------------------------------------------------------------------------
     public Object getFastPropertyValue(int nHandle ) throws 
UnknownPropertyException, 
     WrappedTargetException
@@ -979,7 +977,7 @@ XMultiPropertySet
     {
         listenerContainer.addInterface(XPropertiesChangeListener.class, 
listener);
     }    
-    
+
     // XMultiPropertySet 
-----------------------------------------------------------------------------------
     public void firePropertiesChangeEvent(String[] propNames, 
XPropertiesChangeListener listener)
     {
@@ -1009,7 +1007,7 @@ XMultiPropertySet
                 }
             }
         }
-        
+
         // fire events from unsynchronized section so as to prevent deadlocks
         if (eventCount > 0)
         {
@@ -1047,12 +1045,12 @@ XMultiPropertySet
         }
         return arValues;
     }
-    // XMultiPropertySet 
-----------------------------------------------------------------------------------
    
+    // XMultiPropertySet 
-----------------------------------------------------------------------------------
     public void removePropertiesChangeListener(XPropertiesChangeListener 
xPropertiesChangeListener)
     {
         listenerContainer.removeInterface(XPropertiesChangeListener.class, 
xPropertiesChangeListener);
     }
-    // XMultiPropertySet 
-----------------------------------------------------------------------------------
  
+    // XMultiPropertySet 
-----------------------------------------------------------------------------------
     /** If the array of property names contains an unknown property then it 
will be ignored.
      */
     public void setPropertyValues(String[] propNames, Object[] values) throws 
PropertyVetoException, com.sun.star.lang.IllegalArgumentException, 
com.sun.star.lang.WrappedTargetException
@@ -1070,7 +1068,7 @@ XMultiPropertySet
             
         }
     }
-    
+
     private class PropertySetInfo implements XPropertySetInfo
     {
         public com.sun.star.beans.Property[] getProperties()
@@ -1090,8 +1088,5 @@ XMultiPropertySet
         
     }
 }
-    
-    
-    
-    
+
 
@@ -132,13 +132,13 @@ XMultiPropertySet
      *  a property if you do not care about the Property's handles.
      *  Registration has to occur during
-     *  initialization of the inheriting class (i.e. within the contructor).
+     *  initialization of the inheriting class (i.e. within the constructor).
      *  @param name The property's name (Property.Name).
      *  @param type The property's type (Property.Type).

Modified: openoffice/trunk/main/sal/inc/rtl/strbuf.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/rtl/strbuf.hxx?rev=1832633&r1=1832632&r2=1832633&view=diff
==============================================================================